==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/splitsubtitledialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "splitsubtitledialog.h"
#include <player.h>
#include <commondefs.h>
#include <timeedit.h>

#include <qlabel.h>
#include <qgroupbox.h>
#include <qcheckbox.h>
#include <qtooltip.h>
#include <qlayout.h>

#include <klocale.h>
#include <kpushbutton.h>

using namespace SubtitleComposer;

SplitSubtitleDialog::SplitSubtitleDialog( QWidget* parent ):
	ActionDialog( i18n( "Split Subtitle" ), parent )
{
	QGroupBox* settingsGroupBox = createGroupBox( i18n( "Settings" ) );

	QLabel* splitTimeLabel = new QLabel( settingsGroupBox );
	splitTimeLabel->setText( i18n( "Split time" ) );

	m_splitTimeFromVideoButton = new KPushButton( settingsGroupBox );
	m_splitTimeFromVideoButton->setIconSet( GUI::customIconSet( "time-from-video", KIcon::Toolbar, 16 ) );
	QToolTip::add( m_splitTimeFromVideoButton, i18n( "Set from video length" ) );
	connect( m_splitTimeFromVideoButton, SIGNAL( clicked() ), SLOT( setSplitTimeFromVideo() ) );

	m_splitTimeEdit = new TimeEdit( settingsGroupBox );

	m_shiftNewSubtitleCheckBox = new QCheckBox( settingsGroupBox );
	m_shiftNewSubtitleCheckBox->setText( i18n( "Shift new part backwards after split" ) );
	m_shiftNewSubtitleCheckBox->setChecked( true );

	QHBoxLayout* splitTimeLayout = new QHBoxLayout();
	splitTimeLayout->addStretch();
	splitTimeLayout->addWidget( m_splitTimeFromVideoButton );
	splitTimeLayout->addWidget( m_splitTimeEdit );

	QGridLayout* settingsLayout = createLayout( settingsGroupBox );
	settingsLayout->addWidget( splitTimeLabel, 0, 0 );
	settingsLayout->addLayout( splitTimeLayout, 0, 1 );
	settingsLayout->addMultiCellWidget( m_shiftNewSubtitleCheckBox, 1, 1, 0, 1 );
}

void SplitSubtitleDialog::setSplitTimeFromVideo()
{
	m_splitTimeEdit->setValue( (int)(Player::instance()->length()*1000 + 0.5) );
}

Time SplitSubtitleDialog::splitTime()
{
	return m_splitTimeEdit->value();
}

bool SplitSubtitleDialog::shiftNewSubtitle()
{
	return m_shiftNewSubtitleCheckBox->isChecked();
}

void SplitSubtitleDialog::show()
{
	m_splitTimeFromVideoButton->setEnabled( Player::instance()->state() > Player::Opening );
	if ( m_splitTimeFromVideoButton->isEnabled() )
		setSplitTimeFromVideo();

	ActionDialog::show();
}

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/splitsubtitledialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "splitsubtitledialog.h"
#include <player.h>
#include <commondefs.h>
#include <timeedit.h>

#include <qlabel.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qtooltip.h>
#include <qlayout.h>

#include <klocale.h>
#include <kpushbutton.h>

using namespace SubtitleComposer;

SplitSubtitleDialog::SplitSubtitleDialog( QWidget* parent ):
	ActionDialog( i18n( "Split Subtitle" ), parent )
{
	QButtonGroup* settingsButtonGroup = createButtonGroup( i18n( "Settings" ) );

	QLabel* splitTimeLabel = new QLabel( settingsButtonGroup );
	splitTimeLabel->setText( i18n( "Split time" ) );

	m_splitTimeFromVideoButton = new KPushButton( settingsButtonGroup );
	m_splitTimeFromVideoButton->setIconSet( GUI::customIconSet( "time-from-video", KIcon::Toolbar, 16 ) );
	QToolTip::add( m_splitTimeFromVideoButton, i18n( "Set from video length" ) );
	connect( m_splitTimeFromVideoButton, SIGNAL( clicked() ), SLOT( setSplitTimeFromVideo() ) );

	m_splitTimeEdit = new TimeEdit( settingsButtonGroup );

	m_shiftNewSubtitleCheckBox = new QCheckBox( settingsButtonGroup );
	m_shiftNewSubtitleCheckBox->setText( i18n( "Shift new part backwards after split" ) );
	m_shiftNewSubtitleCheckBox->setChecked( true );

	QHBoxLayout* splitTimeLayout = new QHBoxLayout();
	splitTimeLayout->addStretch();
	splitTimeLayout->addWidget( m_splitTimeFromVideoButton );
	splitTimeLayout->addWidget( m_splitTimeEdit );

	QGridLayout* settingsLayout = createLayout( settingsButtonGroup );
	settingsLayout->addWidget( splitTimeLabel, 0, 0 );
	settingsLayout->addLayout( splitTimeLayout, 0, 1 );
	settingsLayout->addMultiCellWidget( m_shiftNewSubtitleCheckBox, 1, 1, 0, 1 );
}

void SplitSubtitleDialog::setSplitTimeFromVideo()
{
	m_splitTimeEdit->setValue( (int)(Player::instance()->length()*1000 + 0.5) );
}

Time SplitSubtitleDialog::splitTime() const
{
	return m_splitTimeEdit->value();
}

bool SplitSubtitleDialog::shiftNewSubtitle() const
{
	return m_shiftNewSubtitleCheckBox->isChecked();
}

void SplitSubtitleDialog::show()
{
	m_splitTimeFromVideoButton->setEnabled( Player::instance()->state() > Player::Opening );
	if ( m_splitTimeFromVideoButton->isEnabled() )
		setSplitTimeFromVideo();

	ActionDialog::show();
}
